@@ -56,7 +56,7 @@ class OnePlusOneHLS(HLSStream):
 
             self._url = parsed._replace(
                 netloc=self._first_netloc,
-                path="/".join([p for p in path_parts])
+                path="/".join(list(path_parts))
             ).geturl()
         return self._url
 
@@ -100,7 +100,7 @@ class OnePlusOneAPI:
             return
 
         log.debug(f"url_ovva={url_ovva}")
-        url_hls = self.session.http.get(
+        return self.session.http.get(
             url=url_ovva,
             schema=validate.Schema(
                 validate.transform(lambda x: x.split("=")),
@@ -108,7 +108,6 @@ class OnePlusOneAPI:
                 validate.get(1),
             ),
         )
-        return url_hls
 
 
 @pluginmatcher(re.compile(
