@@ -1,9 +1,16 @@
+"""
+$description Live TV channels from RTVS, a Slovak public, state-owned broadcaster.
+$url rtvs.sk
+$type live
+$region Slovakia
+"""
+
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
-from streamlink.utils import parse_json
+from streamlink.stream.hls import HLSStream
+from streamlink.utils.parse import parse_json
 
 
 @pluginmatcher(re.compile(
