@@ -276,7 +276,7 @@ def build_parser():
         help="""
         Set the log message threshold.
 
-        Valid levels are: `none`, `error`, `warning`, `info`, `debug`, `trace`
+        Valid levels are: `none`, `error`, `warning`, `info`, `debug`, `trace`, `all`
         """
     )
     general.add_argument(
@@ -1043,6 +1043,13 @@ def build_parser():
         Example: --ffmpeg-ffmpeg "/usr/local/bin/ffmpeg"
         """
     )
+    transport_ffmpeg.add_argument(
+        "--ffmpeg-no-validation",
+        action="store_true",
+        help="""
+        Disable FFmpeg validation and version logging.
+        """
+    )
     transport_ffmpeg.add_argument(
         "--ffmpeg-verbose",
         action="store_true",
@@ -1263,6 +1270,7 @@ _ARGUMENT_TO_SESSIONOPTION: List[Tuple[str, str, Optional[Callable[[Any], Any]]]
     ("hls_segment_key_uri", "hls-segment-key-uri", None),
     ("hls_audio_select", "hls-audio-select", None),
     ("ffmpeg_ffmpeg", "ffmpeg-ffmpeg", None),
+    ("ffmpeg_no_validation", "ffmpeg-no-validation", None),
     ("ffmpeg_verbose", "ffmpeg-verbose", None),
     ("ffmpeg_verbose_path", "ffmpeg-verbose-path", None),
     ("ffmpeg_fout", "ffmpeg-fout", None),
