@@ -1,16 +1,14 @@
 import json
-from contextlib import contextmanager
 from datetime import datetime as _datetime
 
 from streamlink_cli.utils.formatter import Formatter
 from streamlink_cli.utils.http_server import HTTPServer
 from streamlink_cli.utils.player import find_default_player
-from streamlink_cli.utils.progress import progress
 
 __all__ = [
     "Formatter", "HTTPServer", "JSONEncoder",
     "datetime",
-    "find_default_player", "ignored", "progress",
+    "find_default_player",
 ]
 
 
@@ -24,14 +22,6 @@ class JSONEncoder(json.JSONEncoder):
             return json.JSONEncoder.default(self, obj)
 
 
-@contextmanager
-def ignored(*exceptions):
-    try:
-        yield
-    except exceptions:
-        pass
-
-
 # noinspection PyPep8Naming
 class datetime(_datetime):
     def __str__(self):
